Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func E ¶
E creates a new Error with the given op and arguments. The arguments can be 1: an error, 2: a M instance, 3: an int status code.
Types ¶
type Error ¶
type Error struct {
// contains filtered or unexported fields
}
Error is an error that occured during execution. Includes any error messages and HTTP status code for the response. Implements the Error interface.
func (*Error) Error ¶
Error returns a string containing all the error information. This should not be passed down to any HTTP responses.
func (*Error) Message ¶
Message returns a map of the error messages to be returned in the HTTP response.
Click to show internal directories.
Click to hide internal directories.